=======================
 Invenio-Search v0.1.0
=======================

Invenio-Search v0.1.0 was released on August 19, 2015.

About
-----

Invenio module for information retrieval.

*This is an experimental development preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-search==0.1.0

Documentation
-------------

   http://invenio-search.readthedocs.org/en/v0.1.0

Happy hacking and thanks for flying Invenio-Search.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-search
|   URL: http://invenio-software.org
